import type { AuthenticationPrompt, BaseOptions, GetOptions, SetOptions } from './DataSharingTypes';
export declare const AUTH_PROMPT_DEFAULTS: AuthenticationPrompt;
/**
 * Normalizes the service option for keychain functions.
 *
 * @param serviceOrOptions - Either a service string or an options object
 *                           which includes service configuration.
 * @returns A BaseOptions object with the service set to the provided string,
 *          or the original options object if it was provided.
 * @deprecated Passing a service string is deprecated and will be removed in a future major release.
 */
export declare function normalizeServiceOption(serviceOrOptions?: string | BaseOptions): BaseOptions;
/**
 * Normalizes the server option for keychain functions.
 *
 * @param serverOrOptions - Either a server string or an options object
 *                          which includes server configuration.
 * @returns A BaseOptions object with the server set to the provided string,
 *          or the original options object if it was provided.
 * @deprecated Passing a server string is deprecated and will be removed in a future major release.
 */
export declare function normalizeServerOption(serverOrOptions?: string | BaseOptions): BaseOptions;
/**
 * Normalizes the options for keychain functions.
 *
 * @param serviceOrOptions - Either a service string, a SetOptions object, or a GetOptions object.
 * @returns A SetOptions object if the passed options are of type SetOptions,
 *          and a GetOptions object if the passed options are of type GetOptions.
 * @deprecated Passing a service string or an options object with a string for the authenticationPrompt property is deprecated and will be removed in a future major release.
 */
export declare function normalizeOptions(serviceOrOptions?: string | SetOptions | GetOptions): SetOptions | GetOptions;
//# sourceMappingURL=NormalizeOptionsUtils.ios.d.ts.map